from setuptools import setup
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="ini_config_parser",  # How you named your package folder (MyLib)
    packages=["ini_config_parser"],  # Chose the same as "name"
    version="0.3",  # Start with a small number and increase it with every change you make
    license="MIT",  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description="Provides convenient interface for easily managing multiple enviroments (ex: test, prod) just from one config.ini",  # Give a short description about your library
    author="depozzyx",  # Type in your name
    author_email="2015hhh333@gmail.com",  # Type in your E-Mail
    url="https://github.com/depozzyx/ini_config_parser",  # Provide either the link to your github or to your website
    download_url="https://github.com/depozzyx/ini_config_parser/archive/refs/tags/release-0.2.tar.gz",  # I explain this later on
    keywords=["Ini", "Parser", "Config"],  # Keywords that define your package best
    install_requires=[],  # I get to this in a second
    classifiers=[
        "Development Status :: 4 - Beta",  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        "Intended Audience :: Developers",  # Define that your audience are developers
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",  # Again, pick a license
        "Programming Language :: Python :: 3",  # Specify which pyhton versions that you want to support
    ],
    long_description_content_type="text/markdown",
    long_description=long_description,
)
